==> storify-0.0.6.tgz: package/lib/user.js <==
var path = require('path')
  , Story = require('./story');

var User = function(s, user) {
  var self = this;
  self.info = {};
  Object.keys(user).forEach(function(p) {
    self[p] = self.info[p] = user[p];
  });
  
  this._api = s;
};

User.prototype = {
  
  getStory: function(slug, params, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    var self = this
      , route = path.join('/stories', this.username, slug);
    
    return self.get(route, params, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },

  getStories: function(params, fn) {
    var self = this;
    
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    return self.get('/stories', params, function(e, res) {
      var stories = [];
      res.content.stories.forEach(function(story) {
        story.author = self;
        stories.push(new Story(self._api, story));
      });
      fn(e, stories);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    options.method = 'get';
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    options.method = 'post';
    
    return this._api.request(route, params, options, fn);
  }

};

module.exports = User;

==> storify-0.0.12.tgz: package/lib/user.js <==
var path = require('path')
  , Story = require('./story');

var User = function(s, user) {
  var self = this;
  self.info = {};
  Object.keys(user).forEach(function(p) {
    self[p] = self.info[p] = user[p];
  });
  
  this._api = s;
};

User.prototype = {
  
  getStory: function(slug, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    var self = this
      , route = path.join('/stories', this.username, slug);
    
    return self.get(route, params, options, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },

  getStories: function(params, options, fn) {
    var self = this;
    
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    return self.get('/stories', params, options, function(e, res) {
      var stories = [];
      res.content.stories.forEach(function(story) {
        story.author = self;
        stories.push(new Story(self._api, story));
      });
      fn(e, stories);
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    options.method = 'get';
    
    return this._api.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    options.method = 'post';
    
    return this._api.request(route, params, options, fn);
  }

};

module.exports = User;
